Struct ComponentDescriptor
pub struct ComponentDescriptor { /* private fields */ }Expand description
A value describing a component or resource, which may or may not correspond to a Rust type.
Implementations
impl ComponentDescriptor
impl ComponentDescriptor
pub fn new<T>() -> ComponentDescriptorwhere
T: Component,
pub fn new<T>() -> ComponentDescriptorwhere
T: Component,
Create a new ComponentDescriptor for the type T.
pub unsafe fn new_with_layout(
name: impl Into<Cow<'static, str>>,
storage_type: StorageType,
layout: Layout,
drop: Option<for<'a> unsafe fn(OwningPtr<'a>)>,
mutable: bool,
clone_behavior: ComponentCloneBehavior,
relationship_accessor: Option<RelationshipAccessorInitializer>,
) -> ComponentDescriptor
pub unsafe fn new_with_layout( name: impl Into<Cow<'static, str>>, storage_type: StorageType, layout: Layout, drop: Option<for<'a> unsafe fn(OwningPtr<'a>)>, mutable: bool, clone_behavior: ComponentCloneBehavior, relationship_accessor: Option<RelationshipAccessorInitializer>, ) -> ComponentDescriptor
Create a new ComponentDescriptor.
Panics
Panics if layout does not have a size() that is a multiple of its alignment().
Safety
- the
dropfn must be usable on a pointer with a value of the layoutlayout - the component type must be safe to access from any thread (Send + Sync in rust terms)
relationship_accessormust be valid for this component type if notNone
pub fn new_resource<T>() -> ComponentDescriptorwhere
T: Resource,
👎Deprecated since 0.19.0: use ComponentDescriptor::new()
pub fn new_resource<T>() -> ComponentDescriptorwhere
T: Resource,
use ComponentDescriptor::new()
Create a new ComponentDescriptor for a resource.
The StorageType for resources is always StorageType::Table.
pub fn storage_type(&self) -> StorageType
pub fn storage_type(&self) -> StorageType
Returns a value indicating the storage strategy for the current component.
pub fn type_id(&self) -> Option<TypeId>
pub fn type_id(&self) -> Option<TypeId>
Returns the TypeId of the underlying component type.
Returns None if the component does not correspond to a Rust type.
pub fn name(&self) -> DebugName
pub fn name(&self) -> DebugName
Returns the name of the current component.