Struct Components
pub struct Components { /* private fields */ }Implementations
impl Components
impl Components
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if there are no components registered or queued with this instance. Otherwise, this returns false.
pub fn num_queued(&self) -> usize
pub fn num_queued(&self) -> usize
Returns the number of components registered with this instance.
pub fn any_queued(&self) -> bool
pub fn any_queued(&self) -> bool
Returns true if there are any components registered with this instance. Otherwise, this returns false.
pub fn num_queued_mut(&mut self) -> usize
pub fn num_queued_mut(&mut self) -> usize
A faster version of Self::num_queued.
pub fn any_queued_mut(&mut self) -> bool
pub fn any_queued_mut(&mut self) -> bool
A faster version of Self::any_queued.
pub fn num_registered(&self) -> usize
pub fn num_registered(&self) -> usize
Returns the number of components registered with this instance.
pub fn any_registered(&self) -> bool
pub fn any_registered(&self) -> bool
Returns true if there are any components registered with this instance. Otherwise, this returns false.
pub fn get_info(&self, id: ComponentId) -> Option<&ComponentInfo>
pub fn get_info(&self, id: ComponentId) -> Option<&ComponentInfo>
Gets the metadata associated with the given component, if it is registered.
This will return None if the id is not registered or is queued.
This will return an incorrect result if id did not come from the same world as self. It may return None or a garbage value.
pub fn get_descriptor<'a>(
&'a self,
id: ComponentId,
) -> Option<Cow<'a, ComponentDescriptor>>
pub fn get_descriptor<'a>( &'a self, id: ComponentId, ) -> Option<Cow<'a, ComponentDescriptor>>
Gets the ComponentDescriptor of the component with this ComponentId if it is present.
This will return None only if the id is neither registered nor queued to be registered.
Currently, the Cow will be Cow::Owned if and only if the component is queued. It will be Cow::Borrowed otherwise.
This will return an incorrect result if id did not come from the same world as self. It may return None or a garbage value.
pub fn get_name<'a>(&'a self, id: ComponentId) -> Option<DebugName>
pub fn get_name<'a>(&'a self, id: ComponentId) -> Option<DebugName>
Gets the name of the component with this ComponentId if it is present.
This will return None only if the id is neither registered nor queued to be registered.
This will return an incorrect result if id did not come from the same world as self. It may return None or a garbage value.
pub unsafe fn get_info_unchecked(&self, id: ComponentId) -> &ComponentInfo
pub unsafe fn get_info_unchecked(&self, id: ComponentId) -> &ComponentInfo
Gets the metadata associated with the given component.
Safety
id must be a valid and fully registered ComponentId.
pub fn is_id_valid(&self, id: ComponentId) -> bool
pub fn is_id_valid(&self, id: ComponentId) -> bool
Returns true if the ComponentId is fully registered and valid.
Ids may be invalid if they are still queued to be registered.
Those ids are still correct, but they are not usable in every context yet.
pub fn get_valid_id(&self, type_id: TypeId) -> Option<ComponentId>
pub fn get_valid_id(&self, type_id: TypeId) -> Option<ComponentId>
Type-erased equivalent of Components::valid_component_id().
pub fn valid_component_id<T>(&self) -> Option<ComponentId>where
T: Component,
pub fn valid_component_id<T>(&self) -> Option<ComponentId>where
T: Component,
Returns the ComponentId of the given Component type T if it is fully registered.
If you want to include queued registration, see Components::component_id().
use bevy_ecs::prelude::*;
let mut world = World::new();
#[derive(Component)]
struct ComponentA;
let component_a_id = world.register_component::<ComponentA>();
assert_eq!(component_a_id, world.components().valid_component_id::<ComponentA>().unwrap())See also
pub fn get_valid_resource_id(&self, type_id: TypeId) -> Option<ComponentId>
👎Deprecated since 0.19.0: use get_valid_id
pub fn get_valid_resource_id(&self, type_id: TypeId) -> Option<ComponentId>
use get_valid_id
Type-erased equivalent of Components::valid_resource_id().
pub fn valid_resource_id<T>(&self) -> Option<ComponentId>where
T: Resource,
👎Deprecated since 0.19.0: use valid_component_id
pub fn valid_resource_id<T>(&self) -> Option<ComponentId>where
T: Resource,
use valid_component_id
Returns the ComponentId of the given Resource type T if it is fully registered.
If you want to include queued registration, see Components::resource_id().
use bevy_ecs::prelude::*;
let mut world = World::new();
#[derive(Resource, Default)]
struct ResourceA;
let resource_a_id = world.init_resource::<ResourceA>();
assert_eq!(resource_a_id, world.components().valid_resource_id::<ResourceA>().unwrap())See also
pub fn get_id(&self, type_id: TypeId) -> Option<ComponentId>
pub fn get_id(&self, type_id: TypeId) -> Option<ComponentId>
Type-erased equivalent of Components::component_id().
pub fn component_id<T>(&self) -> Option<ComponentId>where
T: Component,
pub fn component_id<T>(&self) -> Option<ComponentId>where
T: Component,
Returns the ComponentId of the given Component type T.
The returned ComponentId is specific to the Components instance
it was retrieved from and should not be used with another Components
instance.
Returns None if the Component type has not yet been initialized using
ComponentsRegistrator::register_component() or
ComponentsQueuedRegistrator::queue_register_component().
use bevy_ecs::prelude::*;
let mut world = World::new();
#[derive(Component)]
struct ComponentA;
let component_a_id = world.register_component::<ComponentA>();
assert_eq!(component_a_id, world.components().component_id::<ComponentA>().unwrap())See also
pub fn get_resource_id(&self, type_id: TypeId) -> Option<ComponentId>
👎Deprecated since 0.19.0: use get_id
pub fn get_resource_id(&self, type_id: TypeId) -> Option<ComponentId>
use get_id
Type-erased equivalent of Components::resource_id().
pub fn resource_id<T>(&self) -> Option<ComponentId>where
T: Resource,
👎Deprecated since 0.19.0: use component_id
pub fn resource_id<T>(&self) -> Option<ComponentId>where
T: Resource,
use component_id
Returns the ComponentId of the given Resource type T.
The returned ComponentId is specific to the Components instance
it was retrieved from and should not be used with another Components
instance.
Returns None if the Resource type has not yet been initialized using
ComponentsRegistrator::register_resource() or
ComponentsQueuedRegistrator::queue_register_resource().
use bevy_ecs::prelude::*;
let mut world = World::new();
#[derive(Resource, Default)]
struct ResourceA;
let resource_a_id = world.init_resource::<ResourceA>();
assert_eq!(resource_a_id, world.components().resource_id::<ResourceA>().unwrap())See also
pub fn iter_registered(&self) -> impl Iterator<Item = &ComponentInfo>
pub fn iter_registered(&self) -> impl Iterator<Item = &ComponentInfo>
Gets an iterator over all components fully registered with this instance.