ComponentsRegistrator

Struct ComponentsRegistrator 

pub struct ComponentsRegistrator<'w> { /* private fields */ }
A Components wrapper that enables additional features, like registration.

Implementations



impl<'w> ComponentsRegistrator<'w>

pub unsafe fn new( components: &'w mut Components, ids: &'w mut ComponentIds, ) -> ComponentsRegistrator<'w>

Constructs a new ComponentsRegistrator.

Safety

The Components and ComponentIds must match. For example, they must be from the same world.

pub fn as_queued(&self) -> ComponentsQueuedRegistrator<'_>

Converts this ComponentsRegistrator into a ComponentsQueuedRegistrator. This is intended for use to pass this value to a function that requires ComponentsQueuedRegistrator. It is generally not a good idea to queue a registration when you can instead register directly on this type.

pub fn apply_queued_registrations(&mut self)

Applies every queued registration. This ensures that every valid ComponentId is registered, enabling retrieving ComponentInfo, etc.

pub fn register_component<T>(&mut self) -> ComponentId
where T: Component,

Registers a Component of type T with this instance. If a component of this type has already been registered, this will return the ID of the pre-existing component.

See also

pub fn register_component_with_descriptor( &mut self, descriptor: ComponentDescriptor, ) -> ComponentId

Registers a component described by descriptor.

Note

If this method is called multiple times with identical descriptors, a distinct ComponentId will be created for each one.

This can also be used to register resources and non-send data.

Warning

When registering a custom resource be sure to add crate::resource::IsResource as a required component,

See also

pub fn register_resource<T>(&mut self) -> ComponentId
where T: Resource,

👎Deprecated since 0.19.0:

Use register_component::<R>() instead.

Registers a Resource of type T with this instance. If a resource of this type has already been registered, this will return the ID of the pre-existing resource.

See also

pub fn register_non_send<T>(&mut self) -> ComponentId
where T: Any,

Registers a non-send resource of type T with this instance. If a resource of this type has already been registered, this will return the ID of the pre-existing resource.

pub fn any_queued_mut(&mut self) -> bool

Equivalent of Components::any_queued_mut

pub fn num_queued_mut(&mut self) -> usize

Equivalent of Components::any_queued_mut

Methods from Deref<Target = Components>

pub fn len(&self) -> usize

Returns the number of components registered or queued with this instance.

pub fn is_empty(&self) -> bool

Returns true if there are no components registered or queued with this instance. Otherwise, this returns false.

pub fn num_queued(&self) -> usize

Returns the number of components registered with this instance.

pub fn any_queued(&self) -> bool

Returns true if there are any components registered with this instance. Otherwise, this returns false.

pub fn num_registered(&self) -> usize

Returns the number of components registered with this instance.

pub fn any_registered(&self) -> bool

Returns true if there are any components registered with this instance. Otherwise, this returns false.

pub fn get_info(&self, id: ComponentId) -> Option<&ComponentInfo>

Gets the metadata associated with the given component, if it is registered. This will return None if the id is not registered or is queued.

This will return an incorrect result if id did not come from the same world as self. It may return None or a garbage value.

pub fn get_descriptor<'a>( &'a self, id: ComponentId, ) -> Option<Cow<'a, ComponentDescriptor>>

Gets the ComponentDescriptor of the component with this ComponentId if it is present. This will return None only if the id is neither registered nor queued to be registered.

Currently, the Cow will be Cow::Owned if and only if the component is queued. It will be Cow::Borrowed otherwise.

This will return an incorrect result if id did not come from the same world as self. It may return None or a garbage value.

pub fn get_name<'a>(&'a self, id: ComponentId) -> Option<DebugName>

Gets the name of the component with this ComponentId if it is present. This will return None only if the id is neither registered nor queued to be registered.

This will return an incorrect result if id did not come from the same world as self. It may return None or a garbage value.

pub unsafe fn get_info_unchecked(&self, id: ComponentId) -> &ComponentInfo

Gets the metadata associated with the given component.

Safety

id must be a valid and fully registered ComponentId.

pub fn is_id_valid(&self, id: ComponentId) -> bool

Returns true if the ComponentId is fully registered and valid. Ids may be invalid if they are still queued to be registered. Those ids are still correct, but they are not usable in every context yet.

pub fn get_valid_id(&self, type_id: TypeId) -> Option<ComponentId>

Type-erased equivalent of Components::valid_component_id().

pub fn valid_component_id<T>(&self) -> Option<ComponentId>
where T: Component,

Returns the ComponentId of the given Component type T if it is fully registered. If you want to include queued registration, see Components::component_id().

use bevy_ecs::prelude::*;

let mut world = World::new();

#[derive(Component)]
struct ComponentA;

let component_a_id = world.register_component::<ComponentA>();

assert_eq!(component_a_id, world.components().valid_component_id::<ComponentA>().unwrap())
See also

pub fn get_valid_resource_id(&self, type_id: TypeId) -> Option<ComponentId>

👎Deprecated since 0.19.0:

use get_valid_id

Type-erased equivalent of Components::valid_resource_id().

pub fn valid_resource_id<T>(&self) -> Option<ComponentId>
where T: Resource,

👎Deprecated since 0.19.0:

use valid_component_id

Returns the ComponentId of the given Resource type T if it is fully registered. If you want to include queued registration, see Components::resource_id().

use bevy_ecs::prelude::*;

let mut world = World::new();

#[derive(Resource, Default)]
struct ResourceA;

let resource_a_id = world.init_resource::<ResourceA>();

assert_eq!(resource_a_id, world.components().valid_resource_id::<ResourceA>().unwrap())
See also

pub fn get_id(&self, type_id: TypeId) -> Option<ComponentId>

Type-erased equivalent of Components::component_id().

pub fn component_id<T>(&self) -> Option<ComponentId>
where T: Component,

Returns the ComponentId of the given Component type T.

The returned ComponentId is specific to the Components instance it was retrieved from and should not be used with another Components instance.

Returns None if the Component type has not yet been initialized using ComponentsRegistrator::register_component() or ComponentsQueuedRegistrator::queue_register_component().

use bevy_ecs::prelude::*;

let mut world = World::new();

#[derive(Component)]
struct ComponentA;

let component_a_id = world.register_component::<ComponentA>();

assert_eq!(component_a_id, world.components().component_id::<ComponentA>().unwrap())
See also

pub fn get_resource_id(&self, type_id: TypeId) -> Option<ComponentId>

👎Deprecated since 0.19.0:

use get_id

Type-erased equivalent of Components::resource_id().

pub fn resource_id<T>(&self) -> Option<ComponentId>
where T: Resource,

👎Deprecated since 0.19.0:

use component_id

Returns the ComponentId of the given Resource type T.

The returned ComponentId is specific to the Components instance it was retrieved from and should not be used with another Components instance.

Returns None if the Resource type has not yet been initialized using ComponentsRegistrator::register_resource() or ComponentsQueuedRegistrator::queue_register_resource().

use bevy_ecs::prelude::*;

let mut world = World::new();

#[derive(Resource, Default)]
struct ResourceA;

let resource_a_id = world.init_resource::<ResourceA>();

assert_eq!(resource_a_id, world.components().resource_id::<ResourceA>().unwrap())
See also

pub fn iter_registered(&self) -> impl Iterator<Item = &ComponentInfo>

Gets an iterator over all components fully registered with this instance.